@@ -194,5 +194,29 @@ inline AD<Base>::AD(const double &t)
 , taddr_(0)
 { }
 
+// Added by Kasper
+template <class Base>
+inline AD<Base>::AD(const int &t)
+: value_(Base(t))
+, tape_id_(0)
+, taddr_(0)
+{ }
+
+// Added by Kasper
+template <class Base>
+inline AD<Base>::AD(const long int &t)
+: value_(Base(t))
+, tape_id_(0)
+, taddr_(0)
+{ }
+
+// Added by Kasper
+template <class Base>
+inline AD<Base>::AD(const long unsigned int &t)
+: value_(Base(t))
+, tape_id_(0)
+, taddr_(0)
+{ }
+
 } // END_CPPAD_NAMESPACE
 # endif
